<?php

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use DI\Container;
use Slim\Factory\AppFactory;
use MyApp\DB\DB;

require __DIR__ . '/../vendor/autoload.php';

$container = new Container();
AppFactory::setContainer($container);
$app = AppFactory::create();


// Create the Database service
$container->set('db', function () {
    return new DB();
});


$els = [
    ["route" => '/', "title" => "Index"],
    ["route" => "/about", "title" => "About Us"],
    ["route" => '/contact', "title" => 'Contact Us']
];

function navBar($db, Response &$resp, $els = NULL)
{
    if (!$els) {
        $els = $db->getNavBar('nl');
    }
    $resp->getBody()->write('<div id="navbar">');
    foreach ($els as $el) {
        $resp->getBody()->write("<a href=\"" . $el['route'] . "\">" . $el['title'] . "</a><br>");
    }
    $resp->getBody()->write("</div>");
}

$app->get('/', function (Request $request, Response $response, array $args) {
    $db = $this->get('db');
    navBar($db, $response);
    $response->getBody()->write("<h1>Index</h1>");
    return $response;
});

$app->map(["GET", "POST"], '/login', function (Request $request, Response $response, array $args) {

    $form = '<h1>Login form</h1><form action="/login" method="POST">';
    $form .= '<label for="username">Username:</label><input type="text" name="username"/><br/>';
    $form .= '<label for="password">Password:</label><input type="password" name="password"/><br/>';
    $form .= '<input type="submit" name="login" value="Login"/>';
    $form .= '</form>';

    if ($request->getMethod() == "GET") {
        $html = $form;
    } else {
        $formData = $request->getParsedBody();
        $db = $this->get('db');
        $user = new \MyApp\Model\User($db);
        $valid = $user->validateUser($formData["username"], $formData["password"]);
        if ($valid) {
            $html = "<h1>Logged In</h1>";
        } else {
            $html = "<h1>Wrong user/pass combination</h1>";
            $html .= $form;
        }
    }
    $response->getBody()->write($html);
    return $response;
});









$app->get('/contact', function (Request $request, Response $response, array $args) {

    navBar($response);
    $response->getBody()->write("<h1>Contact</h1>");
    return $response;
});

$app->get('/about', function (Request $request, Response $response, array $args) {
    $els = [
        ["route" => '/contact', "title" => 'Contact Us']
    ];
    navBar($response, $els);
    $response->getBody()->write("<h1>About</h1>");
    return $response;
});

$app->run();
